==> QGraphViz-0.0.41.tar.gz: QGraphViz-0.0.41/README.md <==
#   Q G r a p h V i z 
 
 
 
 A   P y Q T   b a s e d   G r a p h V i z   b u i l d e r / r e n d e r e r   ( 1 0 0 %   o p e n s o u r c e ) 
 
 
 
 # #   I n t r o d u c t i o n 
 
 
 
 I   w a s   s e a r c h i n g   f o r   a   h a n d y   t o o l   t o   c o d e   g r a p h s   u s i n g   p y t h o n   t h e n   v i s u a l i z e   t h e m   w i t h i n   m y   s o f t w a r e .   I   f o u n d   a b o u t   g r a p h v i z   w h i c h   i s   a   g r e a t   t o o l   t o   b u i l d   g r a p h s . 
 
 
 
 T h e   p r o b l e m   i s   t h a t   y o u   n e e d   t o   i n s t a l l   t h e   g r a p h v i z   s o f t w a r e   i n   o r d e r   t o   c o m p i l e   y o u r   f i l e   a n d   r e n d e r   i t . 
 
 
 
 T h e r e   i s   a   g r a p h v i z   p a c k a g e   o n   P Y P I   t h a t   a l l o w s   c r e a t i n g   d o t   c o d e   t h a t   c a n   t h e n   b e   p r o c e s s e d   b y   g r a p h v i z ,   b u t   i n   p r a c t i c e ,   y o u   n e e d   t o   i n s t a l l   g r a p h v i z   a n d   s o m e h o w   a d d   i t   t o   y o u r   p a t h   i n   o r d e r   t o   e x e c u t e   t h e   r e n d e r   c o m m a n d . 
 
 
 
 P y G r a p h v i z   i s   a n o t h e r   p a c k a g e   t h a t   c a n   b e   u s e d .   B u t   a s   y o u   c a n   r e a d   i n   t h e i r   d o c u m e n t a t i o n ,   y o u   s t i l l   n e e d   t o   i n s t a l l   G r a p h v i z . 
 
 
 
 I   a l s o   f o u n d   t h i s   v i s u a l i z e r   b a s e d   o n   p y Q t 4 .   I t   i s   a   s i m p l e   Q t   b a s e d   v i s u a l i z e r   t h a t   t r a c k s   t h e   u p d a t e s   o n   t h e   . g v   f i l e   a n d   r e d r a w s   i t   i n   r e a l t i m e : 
 
 D D o r c h / G r a p h V i z L i v e U p d a t e V i e w e r 
 
 
 
 S o   s i n c e   I   d i d n ' t   f i n d   a n y   p a c k a g e   o u t   t h e r e   t h a t   s a t i f i e s   m y   n e e d s ,   I   d e c i d e d   t o   c r e a t e   a   p y Q T 5   b a s e d   G r a p h v i z   t o o l   t h a t   c a n   v i s u a l i z e   G r a p h v i z   c o d e   w i t h o u t   t h e   n e e d   t o   i n s t a l l   G r a p h v i z   a n d   p r o v i d e   i t   w i t h   M I T   l i c e n c e ,   s o   t h a t   o t h e r   p e o p l e   c a n   s i m p l y   u s e   i t   i n   t h e i r   s o f t w a r e . 
 
 
 
 # #   O b j e c t i v e 
 
 
 
 B u i l d   p y t h o n   p y Q T 5   b a s e d   Q W i d g e t   t h a t   c a n   v i s u a l i z e   g r a p h s   a n d   a l l o w   r e a l t i m e   i n t e r a c t i o n   w i t h   g r a p h s   a d d   e d g e s   a n d   n o d e s ,   c h a n g e   a t t r i b u t e s   . . . 
 
 
 
 # #   R e q u i r e m e n t s 
 
 
 
 A s   i t s   n a m e   s u g g e s t s ,   t h i s   m o d u l e   n e e d s   y o u   t o   i n s t a l l   p y q t 5   p a c k a g e   f i r s t . 
 
 
 
 ` ` ` b a s h 
 
 p i p   i n s t a l l   p y q t 5 
 
 ` ` ` 
 
 
 
 # #   I n s t a l l a t i o n 
 
 
 
 ` ` ` b a s h 
 
 p i p   i n s t a l l   Q G r a p h V i z 
 
 ` ` ` 
 
 
 
 # #   A c t u a l   s t a t u s 
 
 
 
 1 .   S i m p l e   g r a p h s   v i s u a l i z a t i o n   ( n o d e s   +   e d g e s ) 
 
 2 .   S i m p l e   g v   f i l e s   r e a d / w r i t e 
 
 3 .   G r a p h   n o d e s   c a n   h o l d   c u s t o m   p a r a m e t e r s   t h a t   c a n   b e   u s e d   b y   t h e   a p p l i c a t i o n 
 
 4 .   G r a p h   n o d e s   a r e   n o w   m a n i p u l a b l e   a n d   w e   c a n   a d d   n o d e s   a n d   l i n k   t h e m   u s i n g   t h e   Q W i d g e t   g u i ,   w a   c a n   a l s o   d e l e t e   n o d e s . 
 
 5 .   T h e   a p p l i c a t i o n   c a n   a c c e p t   o r   r e f u s e   e d g e s   c r e a t i o n   a n d   e v e n   a d d   c u s t o m   p a r a m e t e r s   t o   t h e   e d g e s 
 
 6 .   T h e   n o d e s   c a n   b e   d o u b l e   c l i c k e d   a n d   a n   e v e n t   i s   s e n t   t o   t h e   a p p l i c a t i o n   a l l o w i n g   i t   t o   d o   c u s t o m 
 
 7 .   U s e r   a p p l i c a t i o n   i s   i n f o r m e d   w e n   a   n e w   c o n n e c t i o n   i s   c r e a t e d   b e t w e e n   t w o   n o d e s ,   w h e n   a   n o d e   i s   s e l e c t e d   o r   w h e n   i t   i s   d o u b l e   c l i c k e d . 
 
 8 .   U s e r   a p p l i c a t i o n   i s   i n f o r m e d   w h e n   a   e d g e   i s   s e l e c t e d   o r   d o u b l e   c l i c k e d . 
 
 9 .   O n l y   t w o   s u p p o r t e d   n o d e   s h a p e s   ( b o x   o r   o v a l ) 
 
 1 0 .   A d v a n c e d   n o d e s   s h a p e s   a r e   n o t   y e t   i m p l e m e n t e d 
 
 1 1 .   O n l y   t h e   d o t   l a y o u t   i s   i m p l e m e n t e d 
 
 
 
 # #   E x a m p l e   c o d e 
 
 
 
 Y o u   c a n   f i n d   a n   e x a m p l e   c o d e   f o r   m a n i p u l a t i n g   g r a p h s   i n   [ e x a m p l e s / Q G r a p h V i e w e r . p y ] ( h t t p s : / / g i t h u b . c o m / P a r i s N e o / Q G r a p h V i z / b l o b / m a s t e r / E x a m p l e s / Q G r a p h V i e w e r . p y ) . 
 
 
 
 # #   C h a n g e   l o g 
 
 
 
 T o   v i e w   d i f f e r e n t   c h a n g e s   f r o m   r e l e a s e   t o   t h e   o t h e r   p l e a s e   v i e w   o u r   [ c h a n g e l o g ] ( h t t p s : / / g i t h u b . c o m / P a r i s N e o / Q G r a p h V i z / b l o b / m a s t e r / C h a n g e L o g . m d ) . 
 
 
 
 # #   W a r n i n g 
 
 
 
 I f   y o u   a r e   a i m i n g   t o   e x p o r t   a   . g v   f i l e   o f   y o u r   g r a p h ,   d o n ' t   u s e   i m a g e s   a s   s h a p e s   b e c a u s e   t h i s   i s   n o t   s u p p o r t e d   b y   r e a l   g r a p h v i z   t o o l .   
 
 Y o u   c a n   u s e   i t   s a f e l y   i f   y o u   s a v e   y o u r   g r a p h   i n   o u r   j s o n   f o r m a t . 
 
 
 
 # #   S p e c i a l   t h a n k s 
 
 
 
 H e r e   I ' l l   b e   s i t i n g   t h e   c o n t r i b u t i o n s   o f   o t h e r s   t h a n   m y s e l f   a n d   s h o w   t h e m   g r a t i t u d e   f o r   h e l p   : 
 
 
 
 -   M a n y   t h a n k s   t o   [ E d e r r o d ] ( h t t p s : / / g i t h u b . c o m / E d e r r o d )   f o r   a d d i n g   i c o n   s h a p e d   n o d e s . 
 
 
 
 I f   a n y   o n e   h a s   i d e a s   t o   e n h a n c e   t h i s   t o o l ,   y o u   a r e   w e l c o m e   t o   c o n t r i b u t e . 
 
 

==> QGraphViz-0.0.47.tar.gz: QGraphViz-0.0.47/README.md <==
#   Q G r a p h V i z 
 
 
 
 A   P y Q T   b a s e d   G r a p h V i z   b u i l d e r / r e n d e r e r   ( 1 0 0 %   o p e n s o u r c e ) 
 
 
 
 # #   I n t r o d u c t i o n 
 
 
 
 I   w a s   s e a r c h i n g   f o r   a   h a n d y   t o o l   t o   c o d e   g r a p h s   u s i n g   p y t h o n   t h e n   v i s u a l i z e   t h e m   w i t h i n   m y   s o f t w a r e .   I   f o u n d   a b o u t   g r a p h v i z   w h i c h   i s   a   g r e a t   t o o l   t o   b u i l d   g r a p h s . 
 
 
 
 T h e   p r o b l e m   i s   t h a t   y o u   n e e d   t o   i n s t a l l   t h e   g r a p h v i z   s o f t w a r e   i n   o r d e r   t o   c o m p i l e   y o u r   f i l e   a n d   r e n d e r   i t . 
 
 
 
 T h e r e   i s   a   g r a p h v i z   p a c k a g e   o n   P Y P I   t h a t   a l l o w s   c r e a t i n g   d o t   c o d e   t h a t   c a n   t h e n   b e   p r o c e s s e d   b y   g r a p h v i z ,   b u t   i n   p r a c t i c e ,   y o u   n e e d   t o   i n s t a l l   g r a p h v i z   a n d   s o m e h o w   a d d   i t   t o   y o u r   p a t h   i n   o r d e r   t o   e x e c u t e   t h e   r e n d e r   c o m m a n d . 
 
 
 
 P y G r a p h v i z   i s   a n o t h e r   p a c k a g e   t h a t   c a n   b e   u s e d .   B u t   a s   y o u   c a n   r e a d   i n   t h e i r   d o c u m e n t a t i o n ,   y o u   s t i l l   n e e d   t o   i n s t a l l   G r a p h v i z . 
 
 
 
 I   a l s o   f o u n d   t h i s   v i s u a l i z e r   b a s e d   o n   p y Q t 4 .   I t   i s   a   s i m p l e   Q t   b a s e d   v i s u a l i z e r   t h a t   t r a c k s   t h e   u p d a t e s   o n   t h e   . g v   f i l e   a n d   r e d r a w s   i t   i n   r e a l t i m e : 
 
 D D o r c h / G r a p h V i z L i v e U p d a t e V i e w e r 
 
 
 
 S o   s i n c e   I   d i d n ' t   f i n d   a n y   p a c k a g e   o u t   t h e r e   t h a t   s a t i f i e s   m y   n e e d s ,   I   d e c i d e d   t o   c r e a t e   a   p y Q T 5   b a s e d   G r a p h v i z   t o o l   t h a t   c a n   v i s u a l i z e   G r a p h v i z   c o d e   w i t h o u t   t h e   n e e d   t o   i n s t a l l   G r a p h v i z   a n d   p r o v i d e   i t   w i t h   M I T   l i c e n c e ,   s o   t h a t   o t h e r   p e o p l e   c a n   s i m p l y   u s e   i t   i n   t h e i r   s o f t w a r e . 
 
 
 
 # #   O b j e c t i v e 
 
 
 
 B u i l d   p y t h o n   p y Q T 5   b a s e d   Q W i d g e t   t h a t   c a n   v i s u a l i z e   g r a p h s   a n d   a l l o w   r e a l t i m e   i n t e r a c t i o n   w i t h   g r a p h s   a d d   e d g e s   a n d   n o d e s ,   c h a n g e   a t t r i b u t e s   . . . 
 
 
 
 # #   R e q u i r e m e n t s 
 
 
 
 A s   i t s   n a m e   s u g g e s t s ,   t h i s   m o d u l e   n e e d s   y o u   t o   i n s t a l l   p y q t 5   p a c k a g e   f i r s t . 
 
 
 
 ` ` ` b a s h 
 
 p i p   i n s t a l l   p y q t 5 
 
 ` ` ` 
 
 
 
 # #   I n s t a l l a t i o n 
 
 
 
 ` ` ` b a s h 
 
 p i p   i n s t a l l   Q G r a p h V i z 
 
 ` ` ` 
 
 
 
 # #   A c t u a l   s t a t u s 
 
 
 
 1 .   S i m p l e   g r a p h s   v i s u a l i z a t i o n   ( n o d e s   +   e d g e s ) 
 
 2 .   S i m p l e   g v   f i l e s   r e a d / w r i t e 
 
 3 .   G r a p h   n o d e s   c a n   h o l d   c u s t o m   p a r a m e t e r s   t h a t   c a n   b e   u s e d   b y   t h e   a p p l i c a t i o n 
 
 4 .   G r a p h   n o d e s   a r e   n o w   m a n i p u l a b l e   a n d   w e   c a n   a d d   n o d e s   a n d   l i n k   t h e m   u s i n g   t h e   Q W i d g e t   g u i ,   w a   c a n   a l s o   d e l e t e   n o d e s . 
 
 5 .   T h e   a p p l i c a t i o n   c a n   a c c e p t   o r   r e f u s e   e d g e s   c r e a t i o n   a n d   e v e n   a d d   c u s t o m   p a r a m e t e r s   t o   t h e   e d g e s 
 
 6 .   T h e   n o d e s   c a n   b e   d o u b l e   c l i c k e d   a n d   a n   e v e n t   i s   s e n t   t o   t h e   a p p l i c a t i o n   a l l o w i n g   i t   t o   d o   c u s t o m 
 
 7 .   U s e r   a p p l i c a t i o n   i s   i n f o r m e d   w e n   a   n e w   c o n n e c t i o n   i s   c r e a t e d   b e t w e e n   t w o   n o d e s ,   w h e n   a   n o d e   i s   s e l e c t e d   o r   w h e n   i t   i s   d o u b l e   c l i c k e d . 
 
 8 .   U s e r   a p p l i c a t i o n   i s   i n f o r m e d   w h e n   a   e d g e   i s   s e l e c t e d   o r   d o u b l e   c l i c k e d . 
 
 9 .   O n l y   t w o   s u p p o r t e d   n o d e   s h a p e s   ( b o x   o r   o v a l ) 
 
 1 0 .   A d v a n c e d   n o d e s   s h a p e s   a r e   n o t   y e t   i m p l e m e n t e d 
 
 1 1 .   O n l y   t h e   d o t   l a y o u t   i s   i m p l e m e n t e d 
 
 1 2 .   S u p p o r t e d   s h a p e s   a r e   b o x ,   c i r c l e ,   t r i a n g l e ,   d i a m o n d ,   p o l y g o n   
 
 1 3 .   S u p p o r t e d   c u s t o m   n o d e   s h a p e s   u s i n g   p n g   i m a g e s 
 
 
 
 # #   E x a m p l e   c o d e 
 
 
 
 Y o u   c a n   f i n d   a n   e x a m p l e   c o d e   f o r   m a n i p u l a t i n g   g r a p h s   i n   [ e x a m p l e s / Q G r a p h V i e w e r . p y ] ( h t t p s : / / g i t h u b . c o m / P a r i s N e o / Q G r a p h V i z / b l o b / m a s t e r / E x a m p l e s / Q G r a p h V i e w e r . p y ) . 
 
 
 
 # #   C h a n g e   l o g 
 
 
 
 T o   v i e w   d i f f e r e n t   c h a n g e s   f r o m   r e l e a s e   t o   t h e   o t h e r   p l e a s e   v i e w   o u r   [ c h a n g e l o g ] ( h t t p s : / / g i t h u b . c o m / P a r i s N e o / Q G r a p h V i z / b l o b / m a s t e r / C h a n g e L o g . m d ) . 
 
 
 
 # #   W a r n i n g 
 
 
 
 I f   y o u   a r e   a i m i n g   t o   e x p o r t   a   . g v   f i l e   o f   y o u r   g r a p h ,   d o n ' t   u s e   i m a g e s   a s   s h a p e s   b e c a u s e   t h i s   i s   n o t   s u p p o r t e d   b y   r e a l   g r a p h v i z   t o o l .   
 
 Y o u   c a n   u s e   i t   s a f e l y   i f   y o u   s a v e   y o u r   g r a p h   i n   o u r   j s o n   f o r m a t . 
 
 
 
 # #   S p e c i a l   t h a n k s 
 
 
 
 H e r e   I ' l l   b e   s i t i n g   t h e   c o n t r i b u t i o n s   o f   o t h e r s   t h a n   m y s e l f   a n d   s h o w   t h e m   g r a t i t u d e   f o r   h e l p   : 
 
 
 
 -   M a n y   t h a n k s   t o   [ E d e r r o d ] ( h t t p s : / / g i t h u b . c o m / E d e r r o d )   f o r   a d d i n g   i c o n   s h a p e d   n o d e s . 
 
 
 
 I f   a n y   o n e   h a s   i d e a s   t o   e n h a n c e   t h i s   t o o l ,   y o u   a r e   w e l c o m e   t o   c o n t r i b u t e . 
 
 
